from charms.reactive import when, when_not, set_flag, hook, when_all
from charmhelpers.core.hookenv import status_set, relation_get, log
from charmhelpers.core.host import write_file, service_restart
from charmhelpers.core.templating import render
import charms.apt
import subprocess

@when_not('apt.installed.wordpress')
def install_wordpress_apt():
    charms.apt.queue_install(['wordpress'])
    # sets the 'apt.installed.wordpress' flag when done

@when('apt.installed.wordpress')
@when_not('wordpress.installed')
def install_wordpress():
    # Do your setup here.
    #
    # If your charm has other dependencies before it can install,
    # add those as @when() clauses above., or as additional @when()
    # decorated handlers below
    #
    # See the following for information about reactive charms:
    #
    #  * https://jujucharms.com/docs/devel/developer-getting-started
    #  * https://github.com/juju-solutions/layer-basic#overview
    #

    status_set('maintenance', "configuring wordpress")
    # see https://help.ubuntu.com/lts/serverguide/wordpress.html
    wpconf = """
        Alias /blog /usr/share/wordpress
        <Directory /usr/share/wordpress>
            Options FollowSymLinks
            AllowOverride Limit Options FileInfo
            DirectoryIndex index.php
            Order allow,deny
            Allow from all
        </Directory>
        <Directory /usr/share/wordpress/wp-content>
            Options FollowSymLinks
            Order allow,deny
            Allow from all
        </Directory>
    """
    write_file('/etc/apache2/sites-available/wordpress.conf', wpconf)
    subprocess.call(['a2ensite', 'wordpress'])
    service_restart('apache2')

    status_set('blocked', "wordpress installed, waiting for database")
    set_flag('wordpress.installed')

@when_not('wordpress.installed')
@when_not('apt.installed.wordpress')
def waiting_for_moodle():
    status_set('maintenance', "waiting for apt wordpress installation")

@hook('database-relation-joined')
def database_is_ready():
    status_set('blocked', 'Database is ready (joined) but not configured')
    set_flag('wordpress.database_is_ready')

@when_all('wordpress.installed', 'wordpress.database_is_ready')
def config_php():
    status_set('maintenance', 'configuring wordpress')
    mysql = relation_get()
    log(str(mysql),'INFO')
    render(
            source='config-localhost-php.tmpl',
            target='/etc/wordpress/config-default.php',
            context={
                'my_database': mysql
            })
    status_set('active', 'Ready')

